@@ -1,32 +1,17 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef BTBNODE_H
 #define BTBNODE_H
 
+#include "value.h"
+#include <QByteArray>
 #include <QList>
 #include <QVariant>
-#include <QByteArray>
-#include <util/constants.h>
 #include <ktorrent_export.h>
-#include "value.h"
-
+#include <util/constants.h>
 
 namespace bt
 {
@@ -38,12 +23,14 @@ class BListNode;
  *
  * There are 3 possible pieces of data in b-encoded piece of data.
  * This is the base class for all those 3 things.
-*/
+ */
 class KTORRENT_EXPORT BNode
 {
 public:
     enum Type {
-        VALUE, DICT, LIST
+        VALUE,
+        DICT,
+        LIST,
     };
 
     /**
@@ -81,6 +68,7 @@ public:
 
     /// Print some debugging info
     virtual void printDebugInfo() = 0;
+
 private:
     Type type;
     Uint32 off, len;
@@ -95,11 +83,12 @@ private:
 class KTORRENT_EXPORT BValueNode : public BNode
 {
     Value value;
+
 public:
-    BValueNode(const Value & v, Uint32 off);
+    BValueNode(const Value &v, Uint32 off);
     ~BValueNode() override;
 
-    const Value & data() const
+    const Value &data() const
     {
         return value;
     }
@@ -115,9 +104,10 @@ class KTORRENT_EXPORT BDictNode : public BNode
 {
     struct DictEntry {
         QByteArray key;
-        BNode* node;
+        BNode *node;
     };
     QList<DictEntry> children;
+
 public:
     BDictNode(Uint32 off);
     ~BDictNode() override;
@@ -130,47 +120,47 @@ public:
      * @param key The key
      * @param node The node
      */
-    void insert(const QByteArray & key, BNode* node);
+    void insert(const QByteArray &key, BNode *node);
 
     /**
      * Get a BNode.
      * @param key The key
      * @return The node or 0 if there is no node with has key @a key
      */
-    BNode* getData(const QByteArray & key);
+    BNode *getData(const QByteArray &key);
 
     /**
      * Get a BListNode.
      * @param key The key
      * @return The node or 0 if there is no list node with has key @a key
      */
-    BListNode* getList(const QByteArray& key);
+    BListNode *getList(const QByteArray &key);
 
     /**
      * Get a BDictNode.
      * @param key The key
      * @return The node or 0 if there is no dict node with has key @a key
      */
-    BDictNode* getDict(const QByteArray& key);
+    BDictNode *getDict(const QByteArray &key);
 
     /**
      * Get a BValueNode.
      * @param key The key
      * @return The node or 0 if there is no value node with has key @a key
      */
-    BValueNode* getValue(const QByteArray& key);
+    BValueNode *getValue(const QByteArray &key);
 
     /// Same as getValue, except directly returns an int, if something goes wrong, an error will be thrown
-    int getInt(const QByteArray& key);
+    int getInt(const QByteArray &key);
 
     /// Same as getValue, except directly returns a qint64, if something goes wrong, an error will be thrown
-    qint64 getInt64(const QByteArray& key);
+    qint64 getInt64(const QByteArray &key);
 
     /// Same as getValue, except directly returns a QString, if something goes wrong, an error will be thrown
-    QString getString(const QByteArray& key, QTextCodec* tc);
+    QString getString(const QByteArray &key, QTextCodec *tc);
 
     /// Same as getValue, except directly returns an QByteArray, if something goes wrong, an error will be thrown
-    QByteArray getByteArray(const QByteArray& key);
+    QByteArray getByteArray(const QByteArray &key);
 
     void printDebugInfo() override;
 };
@@ -182,7 +172,8 @@ public:
  */
 class KTORRENT_EXPORT BListNode : public BNode
 {
-    QList<BNode*> children;
+    QList<BNode *> children;
+
 public:
     BListNode(Uint32 off);
     ~BListNode() override;
@@ -191,7 +182,7 @@ public:
      * Append a node to the list.
      * @param node The node
      */
-    void append(BNode* node);
+    void append(BNode *node);
     void printDebugInfo() override;
 
     /// Get the number of nodes in the list.
@@ -205,7 +196,7 @@ public:
      * @param idx The index
      * @return The node or 0 if idx is out of bounds
      */
-    BNode* getChild(Uint32 idx)
+    BNode *getChild(Uint32 idx)
     {
         return children.at(idx);
     }
@@ -216,7 +207,7 @@ public:
      * @return The node or 0 if the index is out of bounds or the element
      *  at postion @a idx isn't a BListNode.
      */
-    BListNode* getList(Uint32 idx);
+    BListNode *getList(Uint32 idx);
 
     /**
      * Get a BDictNode.
@@ -224,7 +215,7 @@ public:
      * @return The node or 0 if the index is out of bounds or the element
      *  at postion @a idx isn't a BDictNode.
      */
-    BDictNode* getDict(Uint32 idx);
+    BDictNode *getDict(Uint32 idx);
 
     /**
      * Get a BValueNode.
@@ -232,7 +223,7 @@ public:
      * @return The node or 0 if the index is out of bounds or the element
      *  at postion @a idx isn't a BValueNode.
      */
-    BValueNode* getValue(Uint32 idx);
+    BValueNode *getValue(Uint32 idx);
 
     /// Same as getValue, except directly returns an int, if something goes wrong, an error will be thrown
     int getInt(Uint32 idx);
@@ -241,7 +232,7 @@ public:
     qint64 getInt64(Uint32 idx);
 
     /// Same as getValue, except directly returns a QString, if something goes wrong, an error will be thrown
-    QString getString(Uint32 idx, QTextCodec* tc);
+    QString getString(Uint32 idx, QTextCodec *tc);
 
     /// Same as getValue, except directly returns an QByteArray, if something goes wrong, an error will be thrown
     QByteArray getByteArray(Uint32 idx);
